package ch.std.jumpstart.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;

// https://www.baeldung.com/spring-security-5-default-password-encoder
// https://spring.io/guides/gs/securing-web/
// https://docs.spring.io/spring-security/site/docs/current/guides/html5/helloworld-boot.html

@Configuration
@EnableWebSecurity
public class InMemoryAuthWebSecurityConfigurer extends WebSecurityConfigurerAdapter {

	public InMemoryAuthWebSecurityConfigurer() {
	}

	@Bean
	public PasswordEncoder encoder() {
		return new BCryptPasswordEncoder();
	}

	@Override
	protected void configure(AuthenticationManagerBuilder auth) throws Exception {
		//PasswordEncoder encoder = PasswordEncoderFactories.createDelegatingPasswordEncoder();
		auth.inMemoryAuthentication().withUser("user").password(encoder().encode("password")).roles("USER").and()
				.withUser("admin").password(encoder().encode("admin")).roles("USER", "ADMIN");
		// auth.inMemoryAuthentication().withUser("user").password("{noop}password").roles("USER").and().withUser("admin")
		// .password("{noop}admin").roles("USER", "ADMIN");
	}

	@Override
	protected void configure(HttpSecurity http) throws Exception {
		http.authorizeRequests().anyRequest().authenticated().and().httpBasic();
	}
}
